Glossary
========

Following are some terms and abbreviations
that are used throughout this report:

.. glossary::

   Distributed Denial of Service (DDoS) attack

      Denial of Service (DoS) attack is an attack where
      the attacker overloads the system with requests.
      DDoS is the distributed DoS attack, that is, the requests are flooding
      from multiple sources.

   Metadata

      Data that describes the information rather than containing
      the information itself.  This can include primary key of a table,
      creation date, etc.

   Participant

      People who participate in a project.

   SQL injection

      SQL injection is an attack where a malicious piece of code is passed
      in an SQL query, which changes the query to the query the attacker wants.

      For example, the attacker may try to create a student with name
      ``John' DROP TABLE Students; --`` and delete the whole table in doing so,
      if the vulnerability is not handled.

   Supervisor

      A person, normally a lecturer, that supervises, supports, and evaluate
      one or several project groups.

   Cross-site scripting (XSS) attack

      Cross-site scripting (XSS) is a code injection attack where
      the attacker inserts client-side scripts into web pages.
